==> tas-1.5.12.tgz: package/test/mocha/6.log_tree/tree.in.forEach.test.js <==
/**
 * Test of Tas.js
 * (c) 2017 Owen Luke
 * https://github.com/tasjs/tas
 * Released under the MIT License.
 */

var tas = require('../tas');
var tester = require('../tester');
var expect = require('chai').expect;

var r1 = [];

describe('6.extensions: tree in forEach', function(){
	it('should create tree logs', function(done){

		// Enable printing log tree in this module.
		tas.enableTree();

		// Save logs into an array instead of printing it immediately.
		tas.tree.logArray.begin();

		var log = tas.tree.log;
		var test = function(done, count) {

			var a = 0;

			tas(function getData(){
				var arr = [1, 2, 3];
				return [arr];
			});

			tas.forEach({
				init: function(element, index){
					a ++; // 2 times
					log(a);
				},

				async: function(){
					setTimeout(function timeout1(){
						tas.next();
					}, 0);

					return "await";
				},

				calc: function(){
					if (count === 1) {
						a ++; // 2 times
					}
				},

				async2: function(){
					setTimeout(function timeout2(){
						a ++; // 2 times
						tas.next();
					}, 0);

					return "await";
				},

				calc2: function(){
					a ++; // 2 times
				}
			});

			tas(function calcMore(){
				a ++; // 9
			});

			tas(function end(){

				// Get logs from array and convert to string.
				var str = tas.tree.logArray.getStr();
				done(count, str);
			});
		};

		var check = function(results){
			expect(results[1] === r1.join('\n')).to.be.equal(true);

			// Disable printing log tree to avoid affect the other modules.
			tas.disableTree();

			done();
		};

		// Run the test twice
		tester.do(test, check, 2);
	});
});

r1 = [
	' 1| getData',
	' 1| forEach',
	' 2|     1: init',
	' 3|         1',
	' 2|     1: async',
	' 2|     1: calc',
	' 2|     1: async2',
	' 2|     1: calc2',
	' 2|     1: ----',
	' 2|     2: init',
	' 3|         5',
	' 2|     2: async',
	' 2|     2: calc',
	' 2|     2: async2',
	' 2|     2: calc2',
	' 2|     2: ----',
	' 2|     3: init',
	' 3|         9',
	' 2|     3: async',
	' 2|     3: calc',
	' 2|     3: async2',
	' 2|     3: calc2',
	' 2|     3: ----',
	' 1| calcMore',
	' 1| end',
	' 1| getData',
	' 1| forEach',
	' 2|     1: init',
	' 3|         1',
	' 2|     1: async',
	' 2|     1: calc',
	' 2|     1: async2',
	' 2|     1: calc2',
	' 2|     1: ----',
	' 2|     2: init',
	' 3|         4',
	' 2|     2: async',
	' 2|     2: calc',
	' 2|     2: async2',
	' 2|     2: calc2',
	' 2|     2: ----',
	' 2|     3: init',
	' 3|         7',
	' 2|     3: async',
	' 2|     3: calc',
	' 2|     3: async2',
	' 2|     3: calc2',
	' 2|     3: ----',
	' 1| calcMore',
	' 1| end'
];

==> tas-1.5.16.tgz: package/test/mocha/6.log_tree/tree.in.forEach.test.js <==
/**
 * Test of Tas.js
 * (c) 2017 Owen Luke
 * https://github.com/tasjs/tas
 * Released under the MIT License.
 */

var tas = require('../tas');
var log = require('../log');
var tester = require('../tester');
var expect = require('chai').expect;

var r1 = [];

describe('6.extensions: tree in forEach', function(){
	it('should create tree logs', function(done){

		// Enable printing log tree in this module.
		tas.enableTree();

		// Save logs into an array instead of printing it immediately.
		tas.tree.logArray.begin();

		var treeLog = tas.tree.log;
		var test = function(done, count) {

			var a = 0;

			tas.begin();

			tas(function getData(){
				var arr = [1, 2, 3];
				return [arr];
			});

			tas.forEach({
				init: function(element, index){
					a ++; // 2 times
					treeLog(a);
				},

				async: function(){
					setTimeout(function timeout1(){
						tas.next();
					}, 0);

					return "await";
				},

				calc: function(){
					if (count === 1) {
						a ++; // 2 times
					}
				},

				async2: function(){
					setTimeout(function timeout2(){
						a ++; // 2 times
						tas.next();
					}, 0);

					return "await";
				},

				calc2: function(){
					a ++; // 2 times
				}
			});

			tas(function calcMore(){
				a ++; // 9
			});

			tas(function end(){

				// Get logs from array and convert to string.
				var str = tas.tree.logArray.getStr();
				done(count, str);
			});
		};

		var check = function(results){
			log(results[1]);
			expect(results[1] === r1.join('\n')).to.be.equal(true);

			// Disable printing log tree to avoid affect the other modules.
			tas.disableTree();

			done();
		};

		// Run the test twice
		tester.do(test, check, 2);
	});
});

r1 = [
	' 1| getData',
	' 1| forEach',
	' 2|     1: init 	// 1, 0',
	' 3|         1',
	' 2|     1: async',
	' 2|     1: calc',
	' 2|     1: async2',
	' 2|     1: calc2',
	' 2|     1: ----',
	' 2|     2: init 	// 2, 1',
	' 3|         5',
	' 2|     2: async',
	' 2|     2: calc',
	' 2|     2: async2',
	' 2|     2: calc2',
	' 2|     2: ----',
	' 2|     3: init 	// 3, 2',
	' 3|         9',
	' 2|     3: async',
	' 2|     3: calc',
	' 2|     3: async2',
	' 2|     3: calc2',
	' 2|     3: ----',
	' 1| calcMore',
	' 1| end',
	' 1| getData',
	' 1| forEach',
	' 2|     1: init 	// 1, 0',
	' 3|         1',
	' 2|     1: async',
	' 2|     1: calc',
	' 2|     1: async2',
	' 2|     1: calc2',
	' 2|     1: ----',
	' 2|     2: init 	// 2, 1',
	' 3|         4',
	' 2|     2: async',
	' 2|     2: calc',
	' 2|     2: async2',
	' 2|     2: calc2',
	' 2|     2: ----',
	' 2|     3: init 	// 3, 2',
	' 3|         7',
	' 2|     3: async',
	' 2|     3: calc',
	' 2|     3: async2',
	' 2|     3: calc2',
	' 2|     3: ----',
	' 1| calcMore',
	' 1| end'
];
